( cd opt/kde/share/doc/HTML/de/ark ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/ark ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kdf ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kdf ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kdm ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kdm ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kig ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kig ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/juk ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/juk ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kpf ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kpf ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/amor ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/amor ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/karm ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/karm ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kate ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kate ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kdvi ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kdvi ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kget ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kget ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kgpg ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kgpg ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kmag ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kmag ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kmid ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kmid ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kmix ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kmix ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kodo ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kodo ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/korn ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/korn ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kppp ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kppp ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/krdc ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/krdc ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/krec ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/krec ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/krfb ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/krfb ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kscd ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kscd ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/ksim ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/ksim ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/lisa ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/lisa ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kxkb ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kxkb ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kalzium ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kalzium ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/katomic ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/katomic ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/ksysguard ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/ksysguard ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kbounce ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kbounce ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kbattleship ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kbattleship ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kaboodle ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kaboodle ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/knewsticker ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/knewsticker ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/khangman ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/khangman ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kfloppy ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kfloppy ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/cervisia ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/cervisia ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/khexedit ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/khexedit ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kpercentage ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kpercentage ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kandy ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kandy ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcalc ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcalc ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kdesu ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kdesu ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcron ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcron ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kdict ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kdict ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kedit ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kedit ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kfind ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kfind ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kiten ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kiten ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kjots ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kjots ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kmail ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kmail ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kmoon ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kmoon ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/knode ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/knode ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kooka ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kooka ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/ksame ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/ksame ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/ksirc ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/ksirc ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/ksysv ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/ksysv ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/ktron ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/ktron ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kuser ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kuser ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kview ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kview ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kwin4 ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kwin4 ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/lskat ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/lskat ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcoloredit ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcoloredit ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/klipper ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/klipper ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kvoctrain ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kvoctrain ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kmousetool ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kmousetool ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/ksnapshot ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/ksnapshot ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/klinkstatus ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/klinkstatus ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kompare ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kompare ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kontact ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kontact ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/konsole ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/konsole ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcachegrind ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcachegrind ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kpackage ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kpackage ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/khelpcenter/faq ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/khelpcenter/faq ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/khelpcenter/quickstart ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/khelpcenter/quickstart ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/khelpcenter/glossary ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/khelpcenter/glossary ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/khelpcenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/khelpcenter ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/khelpcenter/userguide ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/khelpcenter/userguide ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/khelpcenter/visualdict ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/khelpcenter/visualdict ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kshisen ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kshisen ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/ksirtet ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/ksirtet ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/konquest ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/konquest ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kspaceduel ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kspaceduel ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kverbos ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kverbos ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kwallet ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kwallet ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kweather ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kweather ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kwifimanager ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kwifimanager ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kbugbuster ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kbugbuster ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kmenuedit ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kmenuedit ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kioslave ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kioslave ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/flashkard ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/flashkard ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kbackgammon ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kbackgammon ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kaddressbook ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kaddressbook ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/common ; rm -rf fdl-license )
( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/fdl-license fdl-license )
( cd opt/kde/share/doc/HTML/de/common ; rm -rf qpl-license.html )
( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/qpl-license.html qpl-license.html )
( cd opt/kde/share/doc/HTML/de/common ; rm -rf x11-license.html )
( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/x11-license.html x11-license.html )
( cd opt/kde/share/doc/HTML/de/common ; rm -rf 1.png )
( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/1.png 1.png )
( cd opt/kde/share/doc/HTML/de/common ; rm -rf xml.dcl )
( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/xml.dcl xml.dcl )
( cd opt/kde/share/doc/HTML/de/common ; rm -rf 2.png )
( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/2.png 2.png )
( cd opt/kde/share/doc/HTML/de/common ; rm -rf 3.png )
( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/3.png 3.png )
( cd opt/kde/share/doc/HTML/de/common ; rm -rf 4.png )
( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/4.png 4.png )
( cd opt/kde/share/doc/HTML/de/common ; rm -rf 5.png )
( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/5.png 5.png )
( cd opt/kde/share/doc/HTML/de/common ; rm -rf 6.png )
( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/6.png 6.png )
( cd opt/kde/share/doc/HTML/de/common ; rm -rf 7.png )
( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/7.png 7.png )
( cd opt/kde/share/doc/HTML/de/common ; rm -rf 8.png )
( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/8.png 8.png )
( cd opt/kde/share/doc/HTML/de/common ; rm -rf 9.png )
( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/9.png 9.png )
( cd opt/kde/share/doc/HTML/de/common ; rm -rf headerbg.png )
( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/headerbg.png headerbg.png )
( cd opt/kde/share/doc/HTML/de/common ; rm -rf gpl-license.html )
( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/gpl-license.html gpl-license.html )
( cd opt/kde/share/doc/HTML/de/common ; rm -rf mainheader.html )
( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/mainheader.html mainheader.html )
( cd opt/kde/share/doc/HTML/de/common ; rm -rf grad.png )
( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/grad.png grad.png )
( cd opt/kde/share/doc/HTML/de/common ; rm -rf kde-web.css )
( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/kde-web.css kde-web.css )
( cd opt/kde/share/doc/HTML/de/common ; rm -rf kde_logo_bg.png )
( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/kde_logo_bg.png kde_logo_bg.png )
( cd opt/kde/share/doc/HTML/de/common ; rm -rf lgpl-license.html )
( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/lgpl-license.html lgpl-license.html )
( cd opt/kde/share/doc/HTML/de/common ; rm -rf doxygen.css )
( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/doxygen.css doxygen.css )
( cd opt/kde/share/doc/HTML/de/common ; rm -rf web-doctop.png )
( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/web-doctop.png web-doctop.png )
( cd opt/kde/share/doc/HTML/de/common ; rm -rf kde-default.css )
( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/kde-default.css kde-default.css )
( cd opt/kde/share/doc/HTML/de/common ; rm -rf kmenu.png )
( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/kmenu.png kmenu.png )
( cd opt/kde/share/doc/HTML/de/common ; rm -rf footer.html )
( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/footer.html footer.html )
( cd opt/kde/share/doc/HTML/de/common ; rm -rf kde-common.css )
( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
( cd opt/kde/share/doc/HTML/de/common ; rm -rf appheader.html )
( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/appheader.html appheader.html )
( cd opt/kde/share/doc/HTML/de/common ; rm -rf doctop1.png )
( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/doctop1.png doctop1.png )
( cd opt/kde/share/doc/HTML/de/common ; rm -rf doctop2.png )
( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/doctop2.png doctop2.png )
( cd opt/kde/share/doc/HTML/de/common ; rm -rf shadow.png )
( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/shadow.png shadow.png )
( cd opt/kde/share/doc/HTML/de/common ; rm -rf kde_logo.png )
( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
( cd opt/kde/share/doc/HTML/de/common ; rm -rf docheadergears.png )
( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
( cd opt/kde/share/doc/HTML/de/common ; rm -rf fdl-license.html )
( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/fdl-license.html fdl-license.html )
( cd opt/kde/share/doc/HTML/de/common ; rm -rf doctop1a.png )
( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/doctop1a.png doctop1a.png )
( cd opt/kde/share/doc/HTML/de/common ; rm -rf 10.png )
( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/10.png 10.png )
( cd opt/kde/share/doc/HTML/de/common ; rm -rf doctop1b.png )
( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/doctop1b.png doctop1b.png )
( cd opt/kde/share/doc/HTML/de/common ; rm -rf lgpl-license )
( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/lgpl-license lgpl-license )
( cd opt/kde/share/doc/HTML/de/common ; rm -rf mainfooter.html )
( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/mainfooter.html mainfooter.html )
( cd opt/kde/share/doc/HTML/de/common ; rm -rf bottom1.png )
( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/bottom1.png bottom1.png )
( cd opt/kde/share/doc/HTML/de/common ; rm -rf bottom2.png )
( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/bottom2.png bottom2.png )
( cd opt/kde/share/doc/HTML/de/common ; rm -rf header.html )
( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/header.html header.html )
( cd opt/kde/share/doc/HTML/de/common ; rm -rf gpl-license )
( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/gpl-license gpl-license )
( cd opt/kde/share/doc/HTML/de/common ; rm -rf kde-localised.css.template )
( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/kde-localised.css.template kde-localised.css.template )
( cd opt/kde/share/doc/HTML/de/common ; rm -rf bsd-license.html )
( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/bsd-license.html bsd-license.html )
( cd opt/kde/share/doc/HTML/de/common ; rm -rf web-docbottom.png )
( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/web-docbottom.png web-docbottom.png )
( cd opt/kde/share/doc/HTML/de/common ; rm -rf artistic-license.html )
( cd opt/kde/share/doc/HTML/de/common ; ln -sf ../../en/common/artistic-license.html artistic-license.html )
( cd opt/kde/share/doc/HTML/de/kcontrol/kdm ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/kdm ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/smb ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/smb ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/spellchecking ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/spellchecking ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/bell ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/bell ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/arts ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/arts ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/keys ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/keys ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/powerctrl ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/powerctrl ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/kalarmd ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/kalarmd ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/cookies ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/cookies ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/filetypes ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/filetypes ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/desktop ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/desktop ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/cache ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/cache ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/clock ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/clock ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/email ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/email ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/fonts ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/fonts ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/icons ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/icons ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/khtml ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/khtml ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/filemanager ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/filemanager ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/mouse ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/mouse ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/panel ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/panel ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/proxy ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/proxy ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/kmixcfg ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/kmixcfg ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/desktopbehavior ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/desktopbehavior ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/lanbrowser ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/lanbrowser ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/passwords ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/passwords ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/panelappearance ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/panelappearance ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/ebrowsing ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/ebrowsing ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/background ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/background ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/kcmaccess ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/kcmaccess ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/colors ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/colors ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/crypto ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/crypto ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/energy ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/energy ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/kcmstyle ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/kcmstyle ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/netpref ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/netpref ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/kcmlaunch ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/kcmlaunch ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/kcmktalkd ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/kcmktalkd ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/kcmcss ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/kcmcss ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/laptop ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/laptop ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/kxmlrpcd ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/kxmlrpcd ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/kcmnotify ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/kcmnotify ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/kcmsmserver ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/kcmsmserver ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/screensaver ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/screensaver ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/windowmanagement ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/windowmanagement ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/kwindecoration ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/kwindecoration ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/kcmkonsole ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/kcmkonsole ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/language ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/language ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/useragent ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/useragent ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/helpindex ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/helpindex ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/kcmlowbatcrit ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/kcmlowbatcrit ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/kcmlowbatwarn ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/kcmlowbatwarn ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/keyboard ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/keyboard ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/kcmtaskbar ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/kcmtaskbar ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcontrol/kcmfontinst ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcontrol/kcmfontinst ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kicker-applets ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kicker-applets ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/konq-plugins ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/konq-plugins ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kalarm ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kalarm ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kamera ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kamera ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kdeprint ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kdeprint ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kasteroids ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kasteroids ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kbruch ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kbruch ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/keduca ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/keduca ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kgamma ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kgamma ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kmessedwords ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kmessedwords ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kicker ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kicker ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/klines ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/klines ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kmines ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kmines ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kmouth ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kmouth ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kmplot ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kmplot ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/knotes ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/knotes ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kpager ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kpager ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kpaint ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kpaint ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kopete ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kopete ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kpilot ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kpilot ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kpoker ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kpoker ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kruler ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kruler ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/ktalkd ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/ktalkd ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/ksnake ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/ksnake ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kspell ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kspell ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kstars ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kstars ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/ktimer ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/ktimer ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/ktouch ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/ktouch ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kwrite ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kwrite ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kreversi ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kreversi ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/noatun ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/noatun ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kdebugdialog ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kdebugdialog ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kblackbox ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kblackbox ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kcharselect ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kcharselect ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/quanta ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/quanta ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kuickshow ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kuickshow ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kiconedit ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kiconedit ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/klettres ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/klettres ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kfouleggs ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kfouleggs ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kghostview ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kghostview ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/klickety ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/klickety ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kleopatra ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kleopatra ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kjumpingcube ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kjumpingcube ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kenolaba ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kenolaba ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kgpgcertmanager ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kgpgcertmanager ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kwatchgnupg ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kwatchgnupg ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kworldclock ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kworldclock ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/KRegExpEditor ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/KRegExpEditor ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/ksokoban ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/ksokoban ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kteatime ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kteatime ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kmathtool ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kmathtool ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kinfocenter/dma ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kinfocenter/dma ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kinfocenter/pci ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kinfocenter/pci ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kinfocenter/usb ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kinfocenter/usb ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kinfocenter/nics ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kinfocenter/nics ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kinfocenter/scsi ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kinfocenter/scsi ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kinfocenter/interrupts ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kinfocenter/interrupts ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kinfocenter/devices ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kinfocenter/devices ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kinfocenter/blockdevices ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kinfocenter/blockdevices ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kinfocenter/xserver ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kinfocenter/xserver ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kinfocenter/samba ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kinfocenter/samba ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kinfocenter/sound ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kinfocenter/sound ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kinfocenter/partitions ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kinfocenter/partitions ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kinfocenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kinfocenter ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kinfocenter/memory ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kinfocenter/memory ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kinfocenter/pcmcia ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kinfocenter/pcmcia ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kinfocenter/processor ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kinfocenter/processor ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kinfocenter/ioports ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kinfocenter/ioports ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kinfocenter/protocols ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kinfocenter/protocols ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/kate-plugins ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/kate-plugins ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/umbrello ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/umbrello ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/konqueror ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/konqueror ; ln -sf /opt/kde/share/doc/HTML/de/common common )
( cd opt/kde/share/doc/HTML/de/korganizer ; rm -rf common )
( cd opt/kde/share/doc/HTML/de/korganizer ; ln -sf /opt/kde/share/doc/HTML/de/common common )
